@@ -38,7 +38,6 @@ class getter_trnDayStockPrice(baseGetter):
         self.wdc.settingScrape()
 
     def init_recset(self):
-        
         """
         レコードセット初期化
         """
@@ -70,13 +69,18 @@ class getter_trnDayStockPrice(baseGetter):
                 kwargs['brandCd'] = rsMstBrand.fields(mstbrand.brandcd.key).value
                 df = self.getStockDataToDataFrame(**kwargs)
                 Logger.logging.info('<<<<<< Finished Get TrnDayStockPrice Count={0}.'.format(len(df)))
-
+                # mem-check
+                self.cbCheckMem()
+                
         except Exception as e: # その他例外
             Logger.logging.error(str(e))
             raise getterError
         
         return result
     
+    def cbCheckMem():
+        pass
+    
     @Logger.loggerDecorator("getStockDataToDataFrame")
     def getStockDataToDataFrame(self, *args, **kwargs):
 
@@ -97,7 +101,7 @@ class getter_trnDayStockPrice(baseGetter):
         
         # ページロード
         self.wdc.browserCtl.loadPage(stockDataUrl)
-
+        
         # pandasデータを返却する
         return self.wdc.browserCtl.createSearchResultDataFrame(**kwargs)
     
@@ -347,14 +351,14 @@ class getter_trnDayStockPrice(baseGetter):
 
             # 株価データ取得
             rankingTables = bsSrc.find_all(class_="rankingFrame")
-
+            
             # 株価データmodel用意
             rsTrnDayStockPrice = recset[trnDayStockPrice](trnDayStockPrice)
 
             if rankingTables:
                 
                 rankingTable = rankingTables[1]
-                
+
                 # 株価テーブル取得
                 stockList = rankingTable.find_all('tr')
                 for stockListRow in stockList:
